@@ -6,12 +6,10 @@
 ##  TAP: would it make sense to change [A-Z] to [[:alpha:]] or at least [A-Za-z]?
 ##       (for detecting drive letters in paths)
 
-##  Also have intToChar & ASCII from R.oo Version 1.2.7
-
 extract.file.utils.funcs <- function(file=NULL) {
-    # have to have R.utils and R.oo attached ahead of trackObjs when running this func
-    if (any(!is.element(c("package:R.oo", "package:R.utils"), search())))
-        stop("must have packages R.utils and R.oo loaded")
+    # have to have R.utils attached ahead of trackObjs when running this func
+    if (any(!is.element(c("package:R.utils"), search())))
+        stop("must have package R.utils loaded")
     if (!is.null(file)) {
         sink(file)
         on.exit(sink())
@@ -27,14 +25,7 @@ extract.file.utils.funcs <- function(file=NULL) {
     catn(deparse(get("readWindowsShortcut", pos="package:R.utils"), control=character(0), width.cutoff=75))
     cat("\nintToBin <-\n    ")
     catn(deparse(get("intToBin", pos="package:R.utils"), control=character(0), width.cutoff=75))
-    cat("\nASCII <-\nc(\n")
-    charToInt <- get("charToInt.default", pos="package:R.oo")
-    ASCII <- get("ASCII", pos="package:R.oo")
-    intToOct <- get("intToOct", pos="package:R.utils")
-    cat(paste("\"\\", intToOct(charToInt(ASCII)), "\"", sep=""), fill=65, sep=", ")
-    cat(")\n")
-    cat("\nintToChar <-\n    ")
-    catn(deparse(get("intToChar", pos="package:R.oo"), control=character(0), width.cutoff=75))
+    cat("\nintToChar <- function(x) rawToChar(as.raw(x), multiple = TRUE)")
 }
 
 filePath <-
@@ -589,45 +580,11 @@ intToBin <-
     y
 }
 
-# Keep the ASCII table in the backslash format! (don't change to deparsed version)
-ASCII <-
-c(
-"\000", "\001", "\002", "\003", "\004", "\005", "\006", "\007", 
-"\010", "\011", "\012", "\013", "\014", "\015", "\016", "\017", 
-"\020", "\021", "\022", "\023", "\024", "\025", "\026", "\027", 
-"\030", "\031", "\032", "\033", "\034", "\035", "\036", "\037", 
-"\040", "\041", "\042", "\043", "\044", "\045", "\046", "\047", 
-"\050", "\051", "\052", "\053", "\054", "\055", "\056", "\057", 
-"\060", "\061", "\062", "\063", "\064", "\065", "\066", "\067", 
-"\070", "\071", "\072", "\073", "\074", "\075", "\076", "\077", 
-"\100", "\101", "\102", "\103", "\104", "\105", "\106", "\107", 
-"\110", "\111", "\112", "\113", "\114", "\115", "\116", "\117", 
-"\120", "\121", "\122", "\123", "\124", "\125", "\126", "\127", 
-"\130", "\131", "\132", "\133", "\134", "\135", "\136", "\137", 
-"\140", "\141", "\142", "\143", "\144", "\145", "\146", "\147", 
-"\150", "\151", "\152", "\153", "\154", "\155", "\156", "\157", 
-"\160", "\161", "\162", "\163", "\164", "\165", "\166", "\167", 
-"\170", "\171", "\172", "\173", "\174", "\175", "\176", "\177", 
-"\200", "\201", "\202", "\203", "\204", "\205", "\206", "\207", 
-"\210", "\211", "\212", "\213", "\214", "\215", "\216", "\217", 
-"\220", "\221", "\222", "\223", "\224", "\225", "\226", "\227", 
-"\230", "\231", "\232", "\233", "\234", "\235", "\236", "\237", 
-"\240", "\241", "\242", "\243", "\244", "\245", "\246", "\247", 
-"\250", "\251", "\252", "\253", "\254", "\255", "\256", "\257", 
-"\260", "\261", "\262", "\263", "\264", "\265", "\266", "\267", 
-"\270", "\271", "\272", "\273", "\274", "\275", "\276", "\277", 
-"\300", "\301", "\302", "\303", "\304", "\305", "\306", "\307", 
-"\310", "\311", "\312", "\313", "\314", "\315", "\316", "\317", 
-"\320", "\321", "\322", "\323", "\324", "\325", "\326", "\327", 
-"\330", "\331", "\332", "\333", "\334", "\335", "\336", "\337", 
-"\340", "\341", "\342", "\343", "\344", "\345", "\346", "\347", 
-"\350", "\351", "\352", "\353", "\354", "\355", "\356", "\357", 
-"\360", "\361", "\362", "\363", "\364", "\365", "\366", "\367", 
-"\370", "\371", "\372", "\373", "\374", "\375", "\376", "\377"
-)
-
-intToChar <-
-    function (i, ...) 
-{
-    ASCII[i%%256 + 1]
-}
+# Re prior use of "ASCII" table
+# BDR wrote on 2008-04-24 in a private message to maintainers of packages containing "\0":
+# ... strings like "\0" or "\000".  In all released versions of R that has
+# (AFAIK silently) parsed to "", but R 2.8.0 will give a warning.
+# If you really feel you need intToChar, use
+intToChar <- function(x) rawToChar(as.raw(x), multiple = TRUE)
+# But it's dangerous in these days of multibyte locales -- we do have intToUtf8 + iconv.
+# old code: intToChar <- function (i, ...) {ASCII[i%%256 + 1]}
